[← Back to Authentication index](index.md)

# Troubleshooting
| Problem | Solution |
| --- | --- |
| Missing Authorization header | Include the appropriate `Authorization` header with your credentials. |
| Token has expired | Use the refresh token to obtain a new access token. |
| Invalid or expired refresh token | Log in again to receive a new access/refresh token pair. |

